@@ -39,7 +39,11 @@ def scan_volume(path):
         # Ne pas considérer le seul chemin de niveau 1
         if len(path) == 4:
             logger.debug("path: %s, size: %s", path, size)
-            (channel, quality) = path[3].split('.')
+            try:
+                (channel, quality) = path[3].split('.')
+            except ValueError as e:
+                logger.warning("Probably not a normal path. Skip it")
+                next
             if re.match('[2-9][0-9]{3}', path[0]):
                 data.append({'year': path[0], 'network': path[1], 'station': path[2],
                              'channel': channel, 'quality': quality, 'size': size})
@@ -127,11 +131,12 @@ def cli(configfile, force_scan, dryrun, verbose):
     for stat in statistics:
         if re.match('^[1-9XYZ]', stat['network']):
             stat['is_permanent'] = True
-            try:
-                stat['network'] = extender.extend(
-                    stat['network'], int(stat['year']))
-            except ValueError:
-                logger.debug("Network %s exists ?" % stat['network'])
+            if len(stat['network']) < 3 :
+                try:
+                    stat['network'] = extender.extend(
+                        stat['network'], int(stat['year']))
+                except ValueError:
+                    logger.debug("Network %s exists ?" % stat['network'])
         else:
             stat['is_permanent'] = False
         stat['date'] = today
